about summary refs log tree commit diff
path: root/shepherd
diff options
context:
space:
mode:
authorEfraim Flashner2022-10-13 18:28:28 +0300
committerEfraim Flashner2022-10-13 18:28:28 +0300
commit1454b86d292b284b61ff9044dfb4221719732a60 (patch)
tree6bb14e45e9254e5dd014cc4aee1c76852e92e0f3 /shepherd
parentb891e579f1d111c29396a9669798eebebe967963 (diff)
downloadgn-shepherd-services-1454b86d292b284b61ff9044dfb4221719732a60.tar.gz
Update pluto service
Diffstat (limited to 'shepherd')
-rw-r--r--shepherd/init.d/pluto.scm17
1 files changed, 8 insertions, 9 deletions
diff --git a/shepherd/init.d/pluto.scm b/shepherd/init.d/pluto.scm
index dc36730..81c7fe6 100644
--- a/shepherd/init.d/pluto.scm
+++ b/shepherd/init.d/pluto.scm
@@ -1,14 +1,13 @@
 (define pluto
   (make <service>
-	#:provides '(pluto)
-	#:docstring "Run a pluto web server"
-	#:start (make-forkexec-constructor
-		  '("/home/shepherd/run_pluto.sh")
-		  #:log-file "/home/shepherd/logs/pluto.log")
-	#:stop (make-kill-destructor)
-	;; currently running in a screen session
-	#:auto-start? #f
-	#:respawn? #t))
+        #:provides '(pluto)
+        #:docstring "Run a pluto web server"
+        #:start (make-forkexec-constructor
+                  ;; Update the path to runpluto as the guix-profile changes.
+                  '("/home/shepherd/guix-profiles/pluto/bin/guix" "shell" "--container" "--network" "--no-cwd" "julia-visuals" "--" "/gnu/store/wbci39sd5pqrjrb5ak0lkmv9jhnl35kv-julia-visuals-0.0.0-1.e7d670e/runpluto.sh")
+                  #:log-file "/home/shepherd/logs/pluto.log")
+        #:stop (make-kill-destructor)
+        #:respawn? #t))
 (register-services pluto)
 
 (start pluto)